==> rca-precursor-0.1.21.tgz: package/src/middleware/compiler/compiler.js <==
//  @flow
import fs from 'fs';
import path from 'path';
import type { $Request, $Response } from 'express';

import type { IConfig } from '../../../flow/IConfig';
import type { IApp } from '../../../flow/IApp';

import defaultConfig from './../../webpack/defaultConfig';

const resolveHtml = (fileLoader, indexPath) => (
  new Promise((resolve, reject) => (
    fileLoader.readFile(indexPath, (err, fileContents) => {
      let templateString;
      try {
        templateString = fileContents.toString();
      } catch (error) {
        reject('Compilation in progress... Hold tight!');
      } finally {
        resolve(templateString);
      }
    })
  ))
);

export default (app: IApp, config: IConfig) => async (
  req: $Request,
  res: $Response,
  next: Function,
) => {
  const _app = app;
  const {
    isDevEnvironment,
    devCssBundle = defaultConfig.devCssBundle,
    distOutput = defaultConfig.distOutput,
    publicPath = defaultConfig.publicPath,
  } = config;

  const indexPath = (isDevEnvironment)
    ? path.resolve(process.cwd(), 'public/index.html')
    : path.resolve(process.cwd(), './public/index.html');

  const fileLoader = (isDevEnvironment)
    ? app.locals.compiler.outputFileSystem : fs;
    
  //  When any new compilations are finished, grab the outputted CSS
  //  from memory, and send the 'css-update' event to the client
  if (isDevEnvironment) {
    app.locals.compiler.plugin('done', () => {
      const extractedCSS = path.join(process.cwd(), distOutput, publicPath, devCssBundle);
      app.locals.compiler.outputFileSystem.readFile(extractedCSS, (err, data) => {
        if (!err) {
          app.locals.hotMiddleware.publish({ type: 'css-update', value: data.toString() });
        }
      });
    });
  }

  _app.locals.html = (app.locals && app.locals.html)
    ? app.locals.html
    : await resolveHtml(fileLoader, indexPath);

  res.set('content-type', 'text/html');
  next();
};

==> rca-precursor-0.1.22.tgz: package/src/middleware/compiler/compiler.js <==
//  @flow
import fs from 'fs';
import path from 'path';
import type { $Request, $Response } from 'express';

import type { IConfig } from '../../../flow/IConfig';
import type { IApp } from '../../../flow/IApp';

import defaultConfig from './../../webpack/defaultConfig';

const resolveHtml = (fileLoader, indexPath) => (
  new Promise((resolve, reject) => (
    fileLoader.readFile(indexPath, (err, fileContents) => {
      let templateString;
      try {
        templateString = fileContents.toString();
      } catch (error) {
        reject('Compilation in progress... Hold tight!');
      } finally {
        resolve(templateString);
      }
    })
  ))
);

export default (app: IApp, config: IConfig) => async (
  req: $Request,
  res: $Response,
  next: Function,
) => {
  const _app = app;
  const {
    isDevEnvironment,
    devCssBundle = defaultConfig.devCssBundle,
    distOutput = defaultConfig.distOutput,
    publicPath = defaultConfig.publicPath,
  } = config;

  const indexPath = (isDevEnvironment)
    ? path.resolve(process.cwd(), 'public/index.html')
    : path.resolve(process.cwd(), './public/index.html');

  const fileLoader = (isDevEnvironment)
    ? app.locals.compiler.outputFileSystem : fs;

  //  When any new compilations are finished, grab the outputted CSS
  //  from memory, and send the 'css-update' event to the client
  if (isDevEnvironment) {
    app.locals.compiler.plugin('done', () => {
      const extractedCSS = path.join(process.cwd(), distOutput, publicPath, devCssBundle);
      app.locals.compiler.outputFileSystem.readFile(extractedCSS, (err, data) => {
        if (!err) {
          app.locals.hotMiddleware.publish({
            type: 'css-update',
            value: data.toString(),
          });
        }
      });
    });
  }

  _app.locals.html = (app.locals && app.locals.html)
    ? app.locals.html
    : await resolveHtml(fileLoader, indexPath);

  res.set('content-type', 'text/html');
  next();
};
